==> huaweicloudsdkcloudtest-3.1.110-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/list_cases_status_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCasesStatusRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'test_service_id': 'str',
        'body': 'str'
    }

    attribute_map = {
        'test_service_id': 'testServiceId',
        'body': 'body'
    }

    def __init__(self, test_service_id=None, body=None):
        """ListCasesStatusRequest

        The model defined in huaweicloud sdk

        :param test_service_id: projectUUId
        :type test_service_id: str
        :param body: Body of the ListCasesStatusRequest
        :type body: str
        """
        
        

        self._test_service_id = None
        self._body = None
        self.discriminator = None

        self.test_service_id = test_service_id
        if body is not None:
            self.body = body

    @property
    def test_service_id(self):
        """Gets the test_service_id of this ListCasesStatusRequest.

        projectUUId

        :return: The test_service_id of this ListCasesStatusRequest.
        :rtype: str
        """
        return self._test_service_id

    @test_service_id.setter
    def test_service_id(self, test_service_id):
        """Sets the test_service_id of this ListCasesStatusRequest.

        projectUUId

        :param test_service_id: The test_service_id of this ListCasesStatusRequest.
        :type test_service_id: str
        """
        self._test_service_id = test_service_id

    @property
    def body(self):
        """Gets the body of this ListCasesStatusRequest.

        :return: The body of this ListCasesStatusRequest.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ListCasesStatusRequest.

        :param body: The body of this ListCasesStatusRequest.
        :type body: str
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCasesStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudtest-3.1.157-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/list_cases_status_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListCasesStatusRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'test_service_id': 'str',
        'body': 'str'
    }

    attribute_map = {
        'test_service_id': 'testServiceId',
        'body': 'body'
    }

    def __init__(self, test_service_id=None, body=None):
        r"""ListCasesStatusRequest

        The model defined in huaweicloud sdk

        :param test_service_id: projectUUId
        :type test_service_id: str
        :param body: Body of the ListCasesStatusRequest
        :type body: str
        """
        
        

        self._test_service_id = None
        self._body = None
        self.discriminator = None

        self.test_service_id = test_service_id
        if body is not None:
            self.body = body

    @property
    def test_service_id(self):
        r"""Gets the test_service_id of this ListCasesStatusRequest.

        projectUUId

        :return: The test_service_id of this ListCasesStatusRequest.
        :rtype: str
        """
        return self._test_service_id

    @test_service_id.setter
    def test_service_id(self, test_service_id):
        r"""Sets the test_service_id of this ListCasesStatusRequest.

        projectUUId

        :param test_service_id: The test_service_id of this ListCasesStatusRequest.
        :type test_service_id: str
        """
        self._test_service_id = test_service_id

    @property
    def body(self):
        r"""Gets the body of this ListCasesStatusRequest.

        :return: The body of this ListCasesStatusRequest.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this ListCasesStatusRequest.

        :param body: The body of this ListCasesStatusRequest.
        :type body: str
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListCasesStatusRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
